@@ -14,13 +14,16 @@ use Dancer::Factory::Hook;
 use Dancer::Session;
 use Dancer::FileUtils qw(open_file);
 use Dancer::Engine;
+use Dancer::Exception qw(:all);
 
 Dancer::Factory::Hook->instance->install_hooks(
-    qw/before_error_render after_error_render/);
+    qw/before_error_render after_error_render before_error_init/);
 
 sub init {
     my ($self) = @_;
 
+    Dancer::Factory::Hook->instance->execute_hooks('before_error_init', $self);
+
     $self->attributes_defaults(
         title => 'Error ' . $self->code,
         type  => 'runtime error',
@@ -40,6 +43,7 @@ sub has_serializer { setting('serializer') }
 sub code           { $_[0]->{code} }
 sub title          { $_[0]->{title} }
 sub message        { $_[0]->{message} }
+sub exception      { $_[0]->{exception} }
 
 sub backtrace {
     my ($self) = @_;
@@ -171,7 +175,16 @@ sub render {
 
     my $serializer = setting('serializer');
     Dancer::Factory::Hook->instance->execute_hooks('before_error_render', $self);
-    my $response = $serializer ? $self->_render_serialized() : $self->_render_html();
+    my $response;
+    try {
+        $response = $serializer ? $self->_render_serialized() : $self->_render_html();
+    } continuation {
+        my ($continuation) = @_;
+        # If we have a Route continuation, run the after hook, then
+        # propagate the continuation
+        Dancer::Factory::Hook->instance->execute_hooks('after_error_render', $response);
+        $continuation->rethrow();
+    };
     Dancer::Factory::Hook->instance->execute_hooks('after_error_render', $response);
     $response;
 }
@@ -181,6 +194,8 @@ sub _render_serialized {
 
     my $message =
       !ref $self->message ? {error => $self->message} : $self->message;
+    ref $message eq 'HASH' && defined $self->exception
+      and $message->{exception} = $self->exception;
 
     if (setting('show_errors')) {
         Dancer::Response->new(
@@ -212,6 +227,7 @@ sub _render_html {
                    title => $self->title,
                    message => $self->message,
                    code => $self->code,
+                   defined $self->exception ? ( exception => $self->exception ) : (),
                   };
         my $content = Dancer::Engine->engine("template")->apply_renderer($template_name, $ops);
         return Dancer::Response->new(
@@ -322,6 +338,14 @@ The message of the error page.
 
 This is only an attribute getter, you'll have to set it at C<new>.
 
+=head2 exception
+
+The exception that caused the error. If the error was not caused by an
+exception, returns undef. Exceptions are usually objects that inherits of
+Dancer::Exception.
+
+This is only an attribute getter, you'll have to set it at C<new>.
+
 =head1 METHODS/SUBROUTINES
 
 =head2 new
@@ -344,6 +368,10 @@ The code that caused the error.
 
 The message that will appear to the user.
 
+=head3 exception
+
+The exception that will be useable by the rendering.
+
 =head2 backtrace
 
 Create a backtrace of the code where the error is caused.
