@@ -56,10 +56,12 @@ sub render_error {
 sub response_with_headers {
     my $response = Dancer::SharedData->response();
 
-    $response->{headers} ||= HTTP::Headers->new;
-    my $powered_by = "Perl Dancer " . $Dancer::VERSION;
-    $response->header('X-Powered-By' => $powered_by);
-    $response->header('Server'       => $powered_by);
+    if (Dancer::Config::setting('server_tokens')) {
+        $response->{headers} ||= HTTP::Headers->new;
+        my $powered_by = "Perl Dancer " . $Dancer::VERSION;
+        $response->header('X-Powered-By' => $powered_by);
+        $response->header('Server'       => $powered_by);
+    }
 
     return $response;
 }
@@ -127,8 +129,17 @@ sub get_action_response {
         return $class->serialize_response_if_needed() if defined $response && $response->exists;
         # else, get the route handler's response
         Dancer::App->current($handler->{app});
-        $handler->run($request);
-        $class->serialize_response_if_needed();
+        try {
+            $handler->run($request);
+            $class->serialize_response_if_needed();
+        } continuation {
+            my ($continuation) = @_;
+            # If we have a Route continuation, run the after hook, then
+            # propagate the continuation
+            my $resp = Dancer::SharedData->response();
+            Dancer::Factory::Hook->instance->execute_hooks('after', $resp);
+            $continuation->rethrow();
+        };
         my $resp = Dancer::SharedData->response();
         Dancer::Factory::Hook->instance->execute_hooks('after', $resp);
         return $resp;
@@ -143,7 +154,15 @@ sub serialize_response_if_needed {
 
     if (Dancer::App->current->setting('serializer') && $response->content()){
         Dancer::Factory::Hook->execute_hooks('before_serializer', $response);
-        Dancer::Serializer->process_response($response);
+        try {
+            Dancer::Serializer->process_response($response);
+        } continuation {
+            my ($continuation) = @_;
+            # If we have a Route continuation, run the after hook, then
+            # propagate the continuation
+            Dancer::Factory::Hook->execute_hooks('after_serializer', $response);
+            $continuation->rethrow();
+        };
         Dancer::Factory::Hook->execute_hooks('after_serializer', $response);
     }
     return $response;
