@@ -77,7 +77,8 @@ sub process_request {
     return $request
       unless engine->support_content_type($request->content_type);
 
-    return $request unless $request->is_put || $request->is_post;
+    return $request
+      unless $request->is_put || $request->is_post || $request->is_patch;
 
     my $old_params = $request->params('body');
 
@@ -118,13 +119,6 @@ serializers.
 
 =head1 USAGE
 
-=head2 Default engine
-
-The default serializer used by Dancer::Serializer is
-L<Dancer::Serializer::JSON>.
-You can choose another serializer by setting the B<serializer> configuration
-variable.
-
 =head2 Configuration
 
 The B<serializer> configuration variable tells Dancer which serializer to use
